- Packaging fix: the python tag for releases in the 2.0 branch was incorrectly
  set to "py2".  xoutil 2.0+ support only Python 3.4+.

  We're removing the wrongly tagged releases from PyPI__.

__ https://pypi.org/project/xoutil
